@@ -1,5 +1,8 @@
+use std::convert::TryInto;
+
 use err_derive::Error;
-use hyper::StatusCode;
+use hyper::header::HeaderValue;
+use hyper::{HeaderMap, StatusCode};
 
 use garage_util::error::Error as GarageError;
 
@@ -57,11 +60,15 @@ pub enum Error {
 
 	/// The client sent a range header with invalid value
 	#[error(display = "Invalid HTTP range: {:?}", _0)]
-	InvalidRange(#[error(from)] http_range::HttpRangeParseError),
+	InvalidRange(#[error(from)] (http_range::HttpRangeParseError, u64)),
 
 	/// The client sent an invalid request
 	#[error(display = "Bad request: {}", _0)]
 	BadRequest(String),
+
+	/// The client sent a request for an action not supported by garage
+	#[error(display = "Unimplemented action: {}", _0)]
+	NotImplemented(String),
 }
 
 impl From<roxmltree::Error> for Error {
@@ -90,6 +97,8 @@ impl Error {
 			Error::InternalError(_) | Error::Hyper(_) | Error::Http(_) => {
 				StatusCode::INTERNAL_SERVER_ERROR
 			}
+			Error::InvalidRange(_) => StatusCode::RANGE_NOT_SATISFIABLE,
+			Error::NotImplemented(_) => StatusCode::NOT_IMPLEMENTED,
 			_ => StatusCode::BAD_REQUEST,
 		}
 	}
@@ -127,6 +136,22 @@ impl Error {
 			.into()
 		})
 	}
+
+	pub fn add_headers(&self, header_map: &mut HeaderMap<HeaderValue>) {
+		use hyper::header;
+		#[allow(clippy::single_match)]
+		match self {
+			Error::InvalidRange((_, len)) => {
+				header_map.append(
+					header::CONTENT_RANGE,
+					format!("bytes */{}", len)
+						.try_into()
+						.expect("header value only contain ascii"),
+				);
+			}
+			_ => (),
+		}
+	}
 }
 
 /// Trait to map error to the Bad Request error code
